@@ -27,9 +27,6 @@ import gnu.inet.encoding.IDNAException;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileReader;
-import java.io.InputStreamReader;
-import java.io.IOException;
-import java.io.PrintStream;
 import java.util.StringTokenizer;
 
 public class TestIDNA
@@ -55,7 +52,10 @@ public class TestIDNA
 	  "domain\uFF61invalid",
       };
       for ( int i = 0; i < tests.length ; i++ ) {
-	  assert IDNA.toASCII( tests[i] ).equals( "domain.invalid" );
+	  if (!IDNA.toASCII( tests[i] ).equals( "domain.invalid" )) {
+	      System.err.println("Dot-test failed");
+	      System.exit(1);
+	  }
       }
 
       if (args.length == 2) {
