@@ -26,15 +26,6 @@ import gnu.inet.encoding.NFKC;
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileReader;
-import java.io.FileWriter;
-import java.io.IOException;
-import java.io.PrintWriter;
-import java.util.ArrayList;
-import java.util.TreeMap;
-import java.util.TreeSet;
-import java.util.Iterator;
-import java.util.StringTokenizer;
-import java.util.regex.Pattern;
 
 public class TestNFKC
 {
