@@ -1,5 +1,5 @@
 /* tst_tld.c --- Self tests for tld_*().
- * Copyright (C) 2004, 2005, 2006, 2007, 2008  Simon Josefsson.
+ * Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -40,7 +40,7 @@ struct tld
   size_t inlen;
   uint32_t in[100];
   int rc;
-  int errpos;
+  size_t errpos;
 };
 
 static const struct tld tld[] = {
@@ -137,7 +137,6 @@ doit (void)
 	printf ("OK\n");
 
       {
-	size_t errpos;
 	rc = tld_check_8z (tld[i].example, &errpos, NULL);
 	if (rc != tld[i].rc)
 	  {
